#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-BNx1FryXYBnqouoZVbW31
key:                  stack-2.9.3.1-BNx1FryXYBnqouoZVbW31
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  2e18ffb7af6386d47e2f39515ec90480
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-BNx1FryXYBnqouoZVbW31
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-9hyTCG9puEj4dnXsh6uh7k array-0.5.6.0
    async-2.2.6-ITRC11Ox8a3Q3zDt3UwKf
    attoparsec-0.14.4-HxFEqrzE4jlDGISwMuQFm7 base-4.18.2.1
    base64-bytestring-1.2.1.0-3MnxOO7xl0P127Exi8mxw2
    bytestring-0.11.5.3 casa-client-0.0.4-6YoBzvawsoP2wF3wsJR8Ag
    casa-types-0.0.3-D2PsyYpN0eSHCQ8VcNXd7N
    colour-2.3.7-EDSh4MF5MZgLf5AO6Hs3IR
    conduit-1.3.6.1-FIwCK0b1Hr15S6D1xh1znT
    conduit-extra-1.3.8-Ck6pOXJmJPw7MIsaJ1VnN1 containers-0.6.7
    crypton-1.0.5-AZiRYciVzaiGzchrza0W2Y
    crypton-conduit-0.2.3-5PZrVRMjjOX1J3xh5J3OC1 deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-JQjr8PVpkEB4amK6gdUMOF
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.9-VsAeLgvnYtBciT9CaGoHU filepath-1.4.300.1
    fsnotify-0.4.4.0-Lt5utj2eeJAKt3vYYVaEfH
    generic-deriving-1.14.7-4uysLO1BPvDEVVw3DQD5zc
    hackage-security-0.6.3.2-J23DPR6YR6PLfe9dPdOmB0
    hashable-1.4.7.0-Ws19qMM2f99bApawlWBTg
    hi-file-parser-0.1.8.0-68Oz79tQpXm3CqAU4XBxz8
    hpack-0.38.0-81qcn2BfzGtE3FyvXa9OoZ hpc-0.6.2.0
    http-client-0.7.19-EUgGdw3KTvRKxRF4wbGFhk
    http-client-tls-0.3.6.4-HBc6JhLDB5x9b3KS2pRYsA
    http-conduit-2.3.9.1-11rbbdDyCC690BbqwfM9Ni
    http-download-0.2.1.0-40noH4gULnr11SKfVSbgNG
    http-types-0.12.4-1B8W97d7Bm7JkBvipzT6Xa
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-IH4LsBNMWXUK6f4IHiqLkH mtl-2.3.1
    mustache-2.4.3.1-6lCOCTfKDCIJUGE1jiNIiK
    neat-interpolation-0.5.1.4-ACN2Jj3LsNs3n9lYte9Moa
    network-uri-2.6.4.2-6IsL4l5xPlJ2SbjqeOZPL6
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-47hFtTaenhPJTeGKwQSLW6
    pantry-0.8.3-Cnygh61GKZ710Y9RZ2JTXQ
    path-0.9.6-BxhS1zhBGPXAv36OYtgfyJ
    path-io-1.8.2-FuZ8g3n9DutKRzBsYyarXM
    persistent-2.14.6.0-3zzTRZmUktpL8M7RnGGvYV
    persistent-sqlite-2.13.3.0-9Am9UweqAwA7T9wGeDdVEX pretty-1.1.3.6
    primitive-0.9.1.0-J2dxudhiRepI2JRXVzckXt process-1.6.19.0
    project-template-0.2.1.0-JEYXzy7tyAp239TLWXXHoM
    random-1.2.1.3-2fto0SX8B0n5d0nC1pFLHo
    retry-0.9.3.1-LQJiE4gTHP2GyztIPNPndh
    rio-0.1.24.0-ArHJanGKwFR1Xw4IlAGLRy
    rio-prettyprint-0.1.9.0-JwHQbSVLZSGHibUqdI85Np
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl stm-2.5.1.0
    streaming-commons-0.2.3.1-6sqoZsBr4CrIddHndZCdEe
    tar-0.6.0.0-3ZfcE3eDoz3B8p2VtP6TD2 template-haskell-2.20.0.0
    temporary-1.3-6srFELH6ZJ85EWwSBp1olQ text-2.0.2
    text-metrics-0.3.3-AzAQDORzuFZLgS2yyml9KF
    th-reify-many-0.1.10-3nEZfG4JrET7STF9qM5wsn time-1.12.2
    tls-2.0.6-11WKNNOVtKBFdQxC7T6qTD transformers-0.6.1.0
    typed-process-0.2.13.0-HAkQYV8rsLmKAXrwFWyt2n
    unicode-transforms-0.4.0.1-CyoSQ2ueezOEvdVyxqcWTh unix-2.8.4.0
    unix-compat-0.7.4.1-CVij6K5GN6q30I6j86A2Op
    unliftio-0.2.25.1-7sR1Ziz3z9kDMr2BTZq7dj
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP
    vector-0.13.2.0-KNP2q6eDEp8AmnRr9wgHHB
    yaml-0.11.11.2-AvIOnZYyDpQErZ41Aggoi5
    zip-archive-0.4.3.2-8Q0j6ljLLvDzUzPSUe73B
    zlib-0.7.1.0-EYn42Kcbw83G25OrlEVL7c

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

